import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:matrix4_transform/matrix4_transform.dart';

class FlxAuthDialogController extends GetxController
    with SingleGetTickerProviderMixin {
  AnimationController? _animationController;
  AnimationController? get animationController => _animationController;

  Tween<double>? _scaleTween;
  Tween<double>? get scaleTween => _scaleTween;

  Animation<double>? _scaleAnimation;
  Animation<double>? get scaleAnimation => _scaleAnimation;

  Tween<double>? _yOffsetTween;
  Tween<double>? get yOffsetTween => _yOffsetTween;

  Animation<double>? _yOffsetAnimation;
  Animation<double>? get yOffsetAnimation => _yOffsetAnimation;

  Tween<double>? _opacityTween;
  Tween<double>? get opacityTween => _opacityTween;

  Animation<double>? _opacityAnimation;
  Animation<double>? get opacityAnimation => _opacityAnimation;

  Offset _center = Offset(0, 0);
  Offset get center => _center;

  final childKey = GlobalKey();

  @override
  void onInit() {
    _initAnimations();
    _startStartupAnimations();

    super.onInit();
  }

  @override
  void onReady() {
    notifySizeChanges();
    super.onReady();
  }

  void _initAnimations() {
    _animationController = AnimationController(
      vsync: this,
      duration: Duration(milliseconds: 400),
    );

    _scaleTween = new Tween<double>(
      begin: 0.95,
      end: 1,
    );

    _scaleAnimation = _scaleTween!.animate(CurvedAnimation(
      parent: _animationController!,
      curve: Curves.easeInOutCubic,
    ));

    _yOffsetTween = new Tween<double>(
      begin: 10,
      end: 0,
    );

    _yOffsetAnimation = _yOffsetTween!.animate(CurvedAnimation(
      parent: _animationController!,
      curve: Curves.easeInOutCubic,
    ));

    _opacityTween = new Tween<double>(
      begin: 0.5,
      end: 1,
    );

    _opacityAnimation = _opacityTween!.animate(CurvedAnimation(
      parent: _animationController!,
      curve: Curves.ease,
    ));
  }

  void _startStartupAnimations() {
    _animationController!.forward(from: 0);
  }

  void notifySizeChanges() {
    var keyContext = childKey.currentContext!;
    var box = keyContext.findRenderObject() as RenderBox;
    var size = box.size;
    _center = Offset(size.width / 2, size.height / 2);
  }
}
