import 'package:flutter/material.dart';
import 'package:flx_id_overlay/flx_id_overlay.dart';
import 'package:flx_ui/flx_ui.dart';
import 'package:get/get.dart';
import 'package:matrix4_transform/matrix4_transform.dart';

class FlxAuthDialog extends StatelessWidget {
  final Widget child;

  const FlxAuthDialog({
    Key? key,
    required this.child,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Colors.black26,
      child: SafeArea(
        child: Padding(
          padding: EdgeInsets.all(15),
          child: Center(
            child: ConstrainedBox(
              constraints: BoxConstraints(
                maxWidth: 650,
                maxHeight: 900,
              ),
              child: GetBuilder<FlxAuthDialogController>(
                init: FlxAuthDialogController(),
                builder: (controller) => AnimatedBuilder(
                  animation: controller.animationController!,
                  builder: (context, child) => Opacity(
                    opacity: controller.opacityAnimation!.value,
                    child: Transform(
                      transform: Matrix4Transform()
                          .translate(y: controller.yOffsetAnimation!.value)
                          .scale(
                            controller.scaleAnimation!.value,
                            origin: controller.center,
                          )
                          .matrix4,
                      child: SizedBox(
                        key: controller.childKey,
                        child: child!,
                      ),
                    ),
                  ),
                  child: FlxDeepCard(
                    borderRadius: 20,
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(19),
                      child: child,
                    ),
                  ),
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
