import 'package:flutter/material.dart';
import 'package:flx_id_binder/common/flx_id.dart';
import 'package:flx_id_binder/exceptions/client_api_exception.dart';
import 'package:flx_id_binder/models/token_model.dart';
import 'package:flx_id_binder/utils/fingerprint_util.dart';
import 'package:flx_id_overlay/flx_id_overlay.dart';
import 'package:get/get.dart';
import 'package:page_transition/page_transition.dart';

class FlxSignInController extends GetxController {
  final loginController = TextEditingController();
  final passwordController = TextEditingController();

  final FlxSignInfoTunnelModel _model;

  FlxSignInController(this._model);

  String? _errorMessage;
  String? get errorMessage => _errorMessage;

  onSignInButtonTap(BuildContext context) async {
    var login = loginController.text;
    var password = passwordController.text;
    var fingerprint = await FingerprintUtil.buildFingerprint();

    try {
      var result = await FlxId.oauth.signIn(
        email: login,
        password: password,
        appId: _model.appId,
        appSecret: _model.appSecret,
        deviceFingerprint: fingerprint,
        permissions: _model.permissions,
      );

      Navigator.of(context, rootNavigator: true).pop(result);
    } on ClientApiException catch (e) {
      _errorMessage = e.message ?? "Unknown error";
      update();
    }
  }

  onSignUpButtonTap(BuildContext context) {
    Navigator.push(
      context,
      PageTransition(
        type: PageTransitionType.fade,
        child: FlxSignUpNamesScreen(
          signInfoModelNames: _model,
          signUpModelNames: FlxSignUpTunnelModel(),
        ),
      ),
    );
  }
}
