import 'package:flutter/material.dart';
import 'package:flx_id_binder/models/token_model.dart';
import 'package:flx_id_overlay/flx_id_overlay.dart';
import 'package:flx_id_overlay/screens/sign_in/controllers/sign_in_controller.dart';
import 'package:flx_ui/flx_ui.dart';
import 'package:get/get.dart';
import 'package:page_transition/page_transition.dart';

class FlxSignInScreen extends StatelessWidget {
  final FlxSignInfoTunnelModel signInfo;

  const FlxSignInScreen({
    Key? key,
    required this.signInfo,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return FlxAuthScaffold(
      subtitle: "Sign In",
      body: GetBuilder<FlxSignInController>(
        init: FlxSignInController(signInfo),
        builder: (controller) => Column(
          children: [
            Spacer(),
            FlxTextField(
              controller: controller.loginController, // INFO: Info for Ilya
              placeholder: 'E-mail',
            ),
            SizedBox(height: 20),
            FlxTextField(
              controller: controller.passwordController, // INFO: Info for Ilya
              placeholder: 'Password',
              isConceal: true,
            ),
            Spacer(),
            controller.errorMessage != null
                ? Text(
                    controller.errorMessage!,
                    style: FlxTextTheme.text(context).copyWith(
                      color: Colors.red,
                    ),
                  )
                : SizedBox(),
            SizedBox(height: 20),
            FlxSpaciousButton(
              text: 'Sign In',
              onTap: () => controller.onSignInButtonTap(context),
            ),
            SizedBox(height: 20),
            FlxSpaciousButton(
              backgroundColor: FlxColorTheme.primary(context),
              text: 'Sign Up',
              onTap: () => controller.onSignUpButtonTap(context),
            ),
          ],
        ),
      ),
    );
  }
}
