import 'package:flutter/material.dart';
import 'package:flx_id_binder/enums/enums.dart';
import 'package:flx_id_overlay/flx_id_overlay.dart';
import 'package:flx_id_overlay/screens/sign_in_accept/views/views.dart';
import 'package:flx_ui/flx_ui.dart';
import 'package:get/get.dart';

class FlxSignInAcceptScreen extends StatelessWidget {
  final FlxSignInfoTunnelModel signInfo;
  final FlxAppInfoTunnelModel appInfo;

  const FlxSignInAcceptScreen({
    Key? key,
    required this.signInfo,
    required this.appInfo,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Padding(
        padding: EdgeInsets.all(20),
        child: GetBuilder<FlxSignInAcceptController>(
          init: FlxSignInAcceptController(signInfo),
          builder: (controller) => Column(
            children: [
              Spacer(),
              FlxFlatCard(
                width: 100,
                height: 100,
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(11),
                  child: Image.memory(
                    appInfo.info.logoPicture,
                    fit: BoxFit.cover,
                  ),
                ),
              ),
              SizedBox(height: 20),
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  appInfo.info.trusted
                      ? SizedBox(
                          width: 23,
                        )
                      : SizedBox(),
                  Text(
                    ' ${appInfo.info.name} App ',
                    style: FlxTextTheme.subtitle(context),
                  ),
                  appInfo.info.trusted
                      ? Icon(
                          Icons.check_circle_rounded,
                          color: Colors.blue,
                          size: 23,
                        )
                      : SizedBox(),
                ],
              ),
              SizedBox(height: 10),
              Text(
                'Wants to access',
                style: FlxTextTheme.text(context),
              ),
              Spacer(),
              SizedBox(height: 20),
              ConstrainedBox(
                constraints: BoxConstraints(maxHeight: 250),
                child: FlxFlatCard(
                  child: ClipRRect(
                    borderRadius: BorderRadius.circular(11),
                    child: ListView.builder(
                      physics: BouncingScrollPhysics(),
                      itemCount: signInfo.permissions.length,
                      itemBuilder: (context, index) => FlxPermissionListItem(
                        icon: Icons.brightness_5_rounded,
                        title: permissionToString(signInfo.permissions[index]),
                      ),
                    ),
                  ),
                ),
              ),
              SizedBox(height: 20),
              Text(
                'Read the permissions and if you agree for the application to receive permissions to them, click Accept and Login, otherwise Back.',
                style: FlxTextTheme.caption(context),
                textAlign: TextAlign.center,
              ),
              SizedBox(height: 20),
              FlxSpaciousButton(
                text: 'Accept and Continue',
                onTap: () => controller.onAcceptButtonTap(context),
                backgroundColor: Theme.of(context).brightness == Brightness.dark
                    ? Colors.green[700]
                    : Colors.green,
              ),
              SizedBox(height: 20),
              FlxSpaciousButton(
                text: 'Back',
                onTap: () => controller.onBackButtonTap(context),
                backgroundColor: FlxColorTheme.primary(context),
              ),
            ],
          ),
        ),
      ),
    );
  }

  String permissionToString(AuthPermission permission) {
    if (permission == AuthPermission.readNames) {
      return 'Read user name';
    } else if (permission == AuthPermission.readEmail) {
      return 'Read user email';
    } else if (permission == AuthPermission.readAchievements) {
      return 'Read user achievements';
    } else if (permission == AuthPermission.readApplications) {
      return 'Read user application';
    } else if (permission == AuthPermission.readPhotos) {
      return 'Read user photos';
    } else if (permission == AuthPermission.readPrivacy) {
      return 'Read user privacy';
    } else if (permission == AuthPermission.managePhotos) {
      return 'Manege user photos';
    } else if (permission == AuthPermission.manageNames) {
      return 'Manege user name';
    } else if (permission == AuthPermission.manageApplications) {
      return 'Manege user applications';
    } else if (permission == AuthPermission.managePrivacy) {
      return 'Manage user privacy';
    } else if (permission == AuthPermission.permitAchievements) {
      return 'Permit user achievements';
    } else if (permission == AuthPermission.permitExitFromAllDevices) {
      return 'Permit user exit from all devices';
    } else if (permission == AuthPermission.updateEmail) {
      return 'Update user email';
    } else if (permission == AuthPermission.updatePassword) {
      return 'Update user password';
    } else if (permission == AuthPermission.updatePhone) {
      return 'Update user phone';
    }

    return 'Cool';
  }
}
