import 'package:flutter/cupertino.dart';
import 'package:flx_id_binder/exceptions/client_api_exception.dart';
import 'package:flx_id_overlay/flx_id_overlay.dart';
import 'package:get/get.dart';
import 'package:flutter/material.dart';
import 'package:page_transition/page_transition.dart';

class FlxSignUpNamesController extends GetxController {
  final firstNameController = TextEditingController();
  final lastNameController = TextEditingController();
  final nicknameController = TextEditingController();

  final FlxSignInfoTunnelModel signInfoModelNames;
  final FlxSignUpTunnelModel signUpModelNames;

  FlxSignUpNamesController(this.signInfoModelNames, this.signUpModelNames);

  String? _errorMessage;
  String? get errorMessage => _errorMessage;

  bool validateFirstName(String firstName) {
    var reg = RegExp(r'^[A-zёА-я]');

    return firstName.length > 1 &&
        firstName.length < 18 &&
        reg.hasMatch(firstName);
  }

  bool validateLastName(String lastName) {
    var reg = RegExp(r'^[A-zёА-я]');

    return lastName.length > 1 &&
        lastName.length < 18 &&
        reg.hasMatch(lastName);
  }

  validateNickName(String nickname) {
    var reg = RegExp(r'^[A-z0-9_]');

    return nickname.length > 1 &&
        nickname.length < 18 &&
        reg.hasMatch(nickname);
  }

  onSignUpButtonTap(BuildContext context) {
    var firstName = firstNameController.text;
    var lastName = lastNameController.text;
    var nickname = nicknameController.text;

    if (!validateFirstName(firstName)) {
      _errorMessage = "Invalid first name";
    } else if (!validateLastName(lastName)) {
      _errorMessage = "Invalid second name";
    } else if (!validateNickName(nickname)) {
      _errorMessage = "Invalid nickname";
    } else {
      Navigator.push(
        context,
        PageTransition(
          type: PageTransitionType.fade,
          child: FlxSignUpEmailScreen(
            signInfo: signInfoModelNames,
            signUp: FlxSignUpTunnelModel(
              firstName: firstName,
              lastName: lastName,
              nickname: nickname,
              password: signUpModelNames.password,
              email: signUpModelNames.email,
            ),
          ),
        ),
      );
    }

    update();
  }
}
