import 'dart:html';

import 'package:flutter/cupertino.dart';
import 'package:flx_id_binder/common/common.dart';
import 'package:flx_id_binder/exceptions/client_api_exception.dart';
import 'package:flx_id_binder/flx_id_binder.dart';
import 'package:flx_id_overlay/flx_id_overlay.dart';
import 'package:get/get.dart';

class FlxSignUpSelectPhotoController extends GetxController {
  final FlxSignInfoTunnelModel signInfo;
  final FlxSignUpTunnelModel signUp;

  FlxSignUpSelectPhotoController(this.signInfo, this.signUp);

  String? _errorMessage;
  String? get errorMessage => _errorMessage;

  onSignUpButtonTap(BuildContext context) async {
    var fingerprint = await FingerprintUtil.buildFingerprint();

    try {
      await FlxId.oauth.signUp(
        firstName: signUp.firstName!.toLowerCase(),
        lastName: signUp.lastName!.toLowerCase(),
        nickname: signUp.nickname!,
        email: signUp.email!,
        password: signUp.password!,
      );

      var result = await FlxId.oauth.signIn(
        email: signUp.email!,
        password: signUp.password!,
        appId: signInfo.appId,
        appSecret: signInfo.appSecret,
        deviceFingerprint: fingerprint,
        permissions: signInfo.permissions,
      );

      Navigator.of(context, rootNavigator: true).pop(result);
    } on ClientApiException catch (e) {
      _errorMessage = e.message ?? "Unknown error";
      update();
    }
  }
}
