import 'dart:math';

import 'package:flutter/material.dart';
import 'package:flx_id_binder/flx_id_binder.dart';
import 'package:flx_id_overlay/flx_id_overlay.dart';
import 'package:flx_id_overlay/models/app_info_tunnel_model.dart';
import 'package:get/get.dart';
import 'package:page_transition/page_transition.dart';
import 'package:vibration/vibration.dart';

class FlxSplashScreenController extends GetxController
    with SingleGetTickerProviderMixin {
  AnimationController? _animationController;
  AnimationController? get animationController => _animationController;

  Tween<double>? _scaleTween;
  Tween<double>? get scaleTween => _scaleTween;

  Animation<double>? _scaleAnimation;
  Animation<double>? get scaleAnimation => _scaleAnimation;

  Offset _center = Offset(0, 0);
  Offset get center => _center;

  final childKey = GlobalKey();

  BuildContext? context;

  FlxSignInfoTunnelModel? signInfo;

  FlxSplashScreenController(
    this.context,
    this.signInfo,
  ) : super();

  @override
  void onInit() async {
    _initAnimations();
    _startStartupAnimations();
    _navigationToLoginScreen();

    super.onInit();
  }

  @override
  void onReady() {
    notifySizeChanges();
    super.onReady();
  }

  @override
  void onClose() {
    context = null;
    _animationController?.stop();
    super.onClose();
  }

  void _initAnimations() {
    _animationController = AnimationController(
      vsync: this,
      duration: Duration(milliseconds: 750),
      reverseDuration: Duration(seconds: 1),
    )..addStatusListener((status) {
        if (status == AnimationStatus.reverse) {
          heartVibrate();
        }
      });

    _scaleTween = new Tween<double>(
      begin: 0.95,
      end: 1.05,
    );

    _scaleAnimation = _scaleTween!.animate(CurvedAnimation(
      parent: _animationController!,
      curve: Curves.easeInOut,
    ));
  }

  void _startStartupAnimations() {
    _animationController!.repeat(reverse: true);
  }

  void _navigationToLoginScreen() async {
    await Future.delayed(Duration(seconds: Random().nextInt(5) + 1));

    if (context == null) return;

    var appInfo =
        await FlxId.application.getInfo(applicationId: signInfo!.appId);

    Navigator.pushAndRemoveUntil(
      context!,
      PageTransition(
        type: PageTransitionType.fade,
        child: FlxSignInAcceptScreen(
          signInfo: signInfo!,
          appInfo: FlxAppInfoTunnelModel(appInfo),
        ),
      ),
      (e) => false,
    );

    _animationController!.stop();
  }

  void notifySizeChanges() {
    var keyContext = childKey.currentContext!;
    var box = keyContext.findRenderObject() as RenderBox;
    var size = box.size;
    _center = Offset(size.width / 2, size.height / 2);
  }

  void heartVibrate() async {
    await Vibration.vibrate(duration: 50, amplitude: 200);
    await Future.delayed(Duration(milliseconds: 75));
    await Vibration.vibrate(duration: 50, amplitude: 200);
  }
}
